pub struct Connection {
pub port: String,
pub src: String,
}Expand description
One input port that a node wants connected, recorded by name.
Fields
port: StringName of the input port on the node being built.
src: StringReferenced node id (without the @ prefix).